#[repr(u32)]pub enum PrecisionLandMode {
PRECISION_LAND_MODE_DISABLED = 0,
PRECISION_LAND_MODE_OPPORTUNISTIC = 1,
PRECISION_LAND_MODE_REQUIRED = 2,
}Available on crate feature
dialect-asluav only.Expand description
Precision land modes (used in MAV_CMD_NAV_LAND).
Variants
PRECISION_LAND_MODE_DISABLED = 0
Normal (non-precision) landing.
PRECISION_LAND_MODE_OPPORTUNISTIC = 1
Use precision landing if beacon detected when land command accepted, otherwise land normally.
PRECISION_LAND_MODE_REQUIRED = 2
Use precision landing, searching for beacon if not found when land command accepted (land normally if beacon cannot be found).
Implementations