pub struct HIL_STATE_DATA {}Suffers from missing airspeed fields and singularities due to Euler angles. See HIL_STATE_QUATERNION (Superseded since 2013-07)
dialect-asluav only.Expand description
Sent from simulation to autopilot. This packet is useful for high throughput applications such as hardware in the loop simulations.
ID: 90
Fields
time_usec: u64Suffers from missing airspeed fields and singularities due to Euler angles. See HIL_STATE_QUATERNION (Superseded since 2013-07)
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
roll: f32Suffers from missing airspeed fields and singularities due to Euler angles. See HIL_STATE_QUATERNION (Superseded since 2013-07)
Roll angle
pitch: f32Suffers from missing airspeed fields and singularities due to Euler angles. See HIL_STATE_QUATERNION (Superseded since 2013-07)
Pitch angle
yaw: f32Suffers from missing airspeed fields and singularities due to Euler angles. See HIL_STATE_QUATERNION (Superseded since 2013-07)
Yaw angle
rollspeed: f32Suffers from missing airspeed fields and singularities due to Euler angles. See HIL_STATE_QUATERNION (Superseded since 2013-07)
Body frame roll / phi angular speed
pitchspeed: f32Suffers from missing airspeed fields and singularities due to Euler angles. See HIL_STATE_QUATERNION (Superseded since 2013-07)
Body frame pitch / theta angular speed
yawspeed: f32Suffers from missing airspeed fields and singularities due to Euler angles. See HIL_STATE_QUATERNION (Superseded since 2013-07)
Body frame yaw / psi angular speed
lat: i32Suffers from missing airspeed fields and singularities due to Euler angles. See HIL_STATE_QUATERNION (Superseded since 2013-07)
Latitude
lon: i32Suffers from missing airspeed fields and singularities due to Euler angles. See HIL_STATE_QUATERNION (Superseded since 2013-07)
Longitude
alt: i32Suffers from missing airspeed fields and singularities due to Euler angles. See HIL_STATE_QUATERNION (Superseded since 2013-07)
Altitude
vx: i16Suffers from missing airspeed fields and singularities due to Euler angles. See HIL_STATE_QUATERNION (Superseded since 2013-07)
Ground X Speed (Latitude)
vy: i16Suffers from missing airspeed fields and singularities due to Euler angles. See HIL_STATE_QUATERNION (Superseded since 2013-07)
Ground Y Speed (Longitude)
vz: i16Suffers from missing airspeed fields and singularities due to Euler angles. See HIL_STATE_QUATERNION (Superseded since 2013-07)
Ground Z Speed (Altitude)
xacc: i16Suffers from missing airspeed fields and singularities due to Euler angles. See HIL_STATE_QUATERNION (Superseded since 2013-07)
X acceleration
yacc: i16Suffers from missing airspeed fields and singularities due to Euler angles. See HIL_STATE_QUATERNION (Superseded since 2013-07)
Y acceleration
zacc: i16Suffers from missing airspeed fields and singularities due to Euler angles. See HIL_STATE_QUATERNION (Superseded since 2013-07)
Z acceleration
Implementations