pub struct TIME_ESTIMATE_TO_TARGET_DATA {
pub safe_return: i32,
pub land: i32,
pub mission_next_item: i32,
pub mission_end: i32,
pub commanded_action: i32,
}dialect-asluav only.Expand description
Time/duration estimates for various events and actions given the current vehicle state and position.
ID: 380
Fields
safe_return: i32Estimated time to complete the vehicle’s configured “safe return” action from its current position (e.g. RTL, Smart RTL, etc.). -1 indicates that the vehicle is landed, or that no time estimate available.
land: i32Estimated time for vehicle to complete the LAND action from its current position. -1 indicates that the vehicle is landed, or that no time estimate available.
mission_next_item: i32Estimated time for reaching/completing the currently active mission item. -1 means no time estimate available.
mission_end: i32Estimated time for completing the current mission. -1 means no mission active and/or no estimate available.
commanded_action: i32Estimated time for completing the current commanded action (i.e. Go To, Takeoff, Land, etc.). -1 means no action active and/or no estimate available.
Implementations